@@ -28,6 +28,8 @@ use tui::{
 #[structopt(name = "basic")]
 struct CliConfig {
     /// Path to config file. Can be a JSON, TOML, YAML, HJSON or INI file.
+    /// If nothing is specified a file named "config" will be searched for.
+    /// If no config file is found default values will be used.
     #[structopt(short, long)]
     config_file: Option<String>,
 }
@@ -200,15 +202,17 @@ fn get_text_position(text: &str) -> (u16, u16) {
 
 fn main() -> Result<(), Box<dyn Error>> {
     let cli_config = CliConfig::from_args();
-    let config_file = cli_config
-        .config_file
-        .unwrap_or_else(|| "config".to_string());
-    println!("Config file: {:#?}", config_file);
 
     let mut settings = Config::default();
-    if let Err(i) = settings.merge(config::File::with_name(&config_file)) {
-        println!("Failed loading config file {:?}!", i);
-        std::process::exit(1);
+
+    if let Some(config_file) = cli_config.config_file {
+        println!("Config file: {:#?}", config_file);
+        if let Err(i) = settings.merge(config::File::with_name(&config_file)) {
+            println!("Failed loading specified config file {:?}!", i);
+            std::process::exit(1);
+        }
+    } else if settings.merge(config::File::with_name("config")).is_err() {
+        println!("No config file found. Using default values");
     }
 
     let now = Utc::now();
@@ -265,7 +269,7 @@ fn main() -> Result<(), Box<dyn Error>> {
             .create(true)
             .open(&filename.to_string())
             .unwrap();
-        writeln!(output, "## {}", app.title)?;
+        writeln!(output, "{}", app.title)?;
         writeln!(output, "{}", app.text)?;
         writeln!(output)?;
     }
@@ -304,6 +308,9 @@ fn run_app<B: Backend>(terminal: &mut Terminal<B>, mut app: &mut App) -> io::Res
                         KeyCode::Enter => app.text.push('\n'),
                         KeyCode::Char(c) => {
                             app.last_keystroke = Some(Instant::now());
+                            if !app.writing_time.is_running() {
+                                app.writing_time.start();
+                            }
                             app.text.push(c);
                         }
                         KeyCode::Backspace => {
@@ -328,6 +335,7 @@ fn run_app<B: Backend>(terminal: &mut Terminal<B>, mut app: &mut App) -> io::Res
         {
             if last_keystroke.elapsed().as_secs() > keystroke_timeout as u64 {
                 app.last_keystroke = None;
+                app.writing_time.reset();
                 app.text.clear();
             }
         };
